AdvancedButton class

A highly customizable button with advanced features.

Inheritance

Constructors

AdvancedButton({Key? key, double? height, double? width, Color? buttonColor, Color? textColor, double fontSize = 16.0, FontWeight fontWeight = FontWeight.normal, Alignment textAlignment = Alignment.center, Widget? prefixIcon, Widget? suffixIcon, EdgeInsets? buttonPadding = const EdgeInsets.all(8.0), EdgeInsetsGeometry prefixIconPadding = const EdgeInsets.all(4.0), EdgeInsetsGeometry suffixIconPadding = const EdgeInsets.all(4.0), VoidCallback? onPressed, bool isEnabled = true, Color? enabledColor, Color? disabledColor, Gradient? gradient, Color splashColor = Colors.white, double splashRadius = 40.0, BorderRadius borderRadius = const BorderRadius.all(Radius.circular(8.0))})
const

Properties

borderRadius BorderRadius
final
buttonColor Color?
final
buttonPadding EdgeInsets?
final
disabledColor Color?
final
enabledColor Color?
final
fontSize double
final
fontWeight FontWeight
final
gradient Gradient?
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
isEnabled bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPressed VoidCallback?
final
prefixIcon Widget?
final
prefixIconPadding EdgeInsetsGeometry
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
splashColor Color
final
splashRadius double
final
suffixIcon Widget?
final
suffixIconPadding EdgeInsetsGeometry
final
textAlignment Alignment
final
textColor Color?
final
width double?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<AdvancedButton>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited